@@ -280,38 +280,7 @@ class Cube : public BaseCube< eT, Cube<eT> >
   inline const_slice_iterator end_slice(const uword slice_num)   const;
 
 
-  template<uword fixed_n_rows, uword fixed_n_cols, uword fixed_n_slices>
-  class fixed : public Cube<eT>
-    {
-    private:
-    
-    static const uword fixed_n_elem = fixed_n_rows * fixed_n_cols * fixed_n_slices;
-    
-    arma_aligned Mat<eT>* mat_ptrs_local_extra[ (fixed_n_slices > Cube_prealloc::mat_ptrs_size) ? fixed_n_slices : 1 ];
-    arma_aligned eT       mem_local_extra     [ (fixed_n_elem   > Cube_prealloc::mem_n_elem)    ? fixed_n_elem   : 1 ];
-    
-    arma_inline void mem_setup();
-    
-    
-    public:
-    
-    inline fixed() { mem_setup(); }
-    
-    inline const Cube& operator=(const eT val) { mem_setup(); Cube<eT>::operator=(val); return *this; }
-    
-    template<typename T1>
-    inline fixed(const BaseCube<eT,T1>& A) { mem_setup(); Cube<eT>::operator=(A.get_ref()); }
-    
-    template<typename T1>
-    inline const Cube& operator=(const BaseCube<eT,T1>& A) { Cube<eT>::operator=(A.get_ref()); return *this; }
-    
-    template<typename T1, typename T2>
-    inline explicit fixed(const BaseCube<pod_type,T1>& A, const BaseCube<pod_type,T2>& B) { mem_setup(); Cube<eT>::init(A,B); }
-    
-    
-    // using Cube<eT>::operator();
-    // TODO: overload operator(), operator[] and .at() to allow faster element access
-    };
+  template<uword fixed_n_rows, uword fixed_n_cols, uword fixed_n_slices> class fixed;
   
   
   protected:
@@ -341,6 +310,42 @@ class Cube : public BaseCube< eT, Cube<eT> >
 
 
 
+template<typename eT>
+template<uword fixed_n_rows, uword fixed_n_cols, uword fixed_n_slices>
+class Cube<eT>::fixed : public Cube<eT>
+  {
+  private:
+  
+  static const uword fixed_n_elem = fixed_n_rows * fixed_n_cols * fixed_n_slices;
+  
+  arma_aligned Mat<eT>* mat_ptrs_local_extra[ (fixed_n_slices > Cube_prealloc::mat_ptrs_size) ? fixed_n_slices : 1 ];
+  arma_aligned eT       mem_local_extra     [ (fixed_n_elem   > Cube_prealloc::mem_n_elem)    ? fixed_n_elem   : 1 ];
+  
+  arma_inline void mem_setup();
+  
+  
+  public:
+  
+  inline fixed() { mem_setup(); }
+  
+  inline const Cube& operator=(const eT val) { mem_setup(); Cube<eT>::operator=(val); return *this; }
+  
+  template<typename T1>
+  inline fixed(const BaseCube<eT,T1>& A) { mem_setup(); Cube<eT>::operator=(A.get_ref()); }
+  
+  template<typename T1>
+  inline const Cube& operator=(const BaseCube<eT,T1>& A) { Cube<eT>::operator=(A.get_ref()); return *this; }
+  
+  template<typename T1, typename T2>
+  inline explicit fixed(const BaseCube<pod_type,T1>& A, const BaseCube<pod_type,T2>& B) { mem_setup(); Cube<eT>::init(A,B); }
+  
+  
+  // using Cube<eT>::operator();
+  // TODO: overload operator(), operator[] and .at() to allow faster element access
+  };
+
+
+
 class Cube_aux
   {
   public:
