@@ -40,7 +40,7 @@ accu_proxy_linear(const Proxy<T1>& P)
   
   if(i < n_elem)
     {
-    val1 += A[i];
+    val1 += A[i];   // equivalent to: val1 += A[n_elem-1];
     }
   
   return (val1 + val2);
@@ -86,12 +86,12 @@ accu_proxy_at(const Proxy<T1>& P)
 template<typename T1>
 arma_hot
 inline
-typename T1::elem_type
-accu(const Base<typename T1::elem_type,T1>& X)
+typename enable_if2< is_arma_type<T1>::value, typename T1::elem_type >::result
+accu(const T1& X)
   {
   arma_extra_debug_sigprint();
   
-  const Proxy<T1> P(X.get_ref());
+  const Proxy<T1> P(X);
   
   return (Proxy<T1>::prefer_at_accessor == false) ? accu_proxy_linear(P) : accu_proxy_at(P);
   }
@@ -156,6 +156,7 @@ accu(const mtOp<uword,T1,op_rel_noteq>& X)
 
 //! accumulate the elements of a subview (submatrix)
 template<typename eT>
+arma_hot
 arma_pure
 arma_warn_unused
 inline
@@ -209,6 +210,7 @@ accu(const subview<eT>& X)
 
 
 template<typename eT>
+arma_hot
 arma_pure
 arma_warn_unused
 inline
