@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2011 NICTA (www.nicta.com.au)
-// Copyright (C) 2008-2011 Conrad Sanderson
+// Copyright (C) 2008-2012 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2012 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -35,32 +35,32 @@ randn()
 
 //! Generate a vector with all elements set to random values with a gaussian distribution (zero mean, unit variance)
 arma_inline
-const Gen<vec::elem_type, gen_randn>
+const Gen<vec, gen_randn>
 randn(const uword n_elem)
   {
   arma_extra_debug_sigprint();
   
-  return Gen<vec::elem_type, gen_randn>(n_elem, 1);
+  return Gen<vec, gen_randn>(n_elem, 1);
   }
 
 
 
-template<typename vec_type>
+template<typename obj_type>
 arma_inline
-const Gen<typename vec_type::elem_type, gen_randn>
-randn(const uword n_elem, const arma_empty_class junk1 = arma_empty_class(), const typename arma_Mat_Col_Row_only<vec_type>::result* junk2 = 0)
+const Gen<obj_type, gen_randn>
+randn(const uword n_elem, const arma_empty_class junk1 = arma_empty_class(), const typename arma_Mat_Col_Row_only<obj_type>::result* junk2 = 0)
   {
   arma_extra_debug_sigprint();
   arma_ignore(junk1);
   arma_ignore(junk2);
   
-  if(is_Row<vec_type>::value == true)
+  if(is_Row<obj_type>::value == true)
     {
-    return Gen<typename vec_type::elem_type, gen_randn>(1, n_elem);
+    return Gen<obj_type, gen_randn>(1, n_elem);
     }
   else
     {
-    return Gen<typename vec_type::elem_type, gen_randn>(n_elem, 1);
+    return Gen<obj_type, gen_randn>(n_elem, 1);
     }
   }
 
@@ -68,25 +68,35 @@ randn(const uword n_elem, const arma_empty_class junk1 = arma_empty_class(), con
 
 //! Generate a dense matrix with all elements set to random values with a gaussian distribution (zero mean, unit variance)
 arma_inline
-const Gen<mat::elem_type, gen_randn>
+const Gen<mat, gen_randn>
 randn(const uword n_rows, const uword n_cols)
   {
   arma_extra_debug_sigprint();
   
-  return Gen<mat::elem_type, gen_randn>(n_rows, n_cols);
+  return Gen<mat, gen_randn>(n_rows, n_cols);
   }
 
 
 
-template<typename mat_type>
+template<typename obj_type>
 arma_inline
-const Gen<typename mat_type::elem_type, gen_randn>
-randn(const uword n_rows, const uword n_cols, const typename arma_Mat_Col_Row_only<mat_type>::result* junk = 0)
+const Gen<obj_type, gen_randn>
+randn(const uword n_rows, const uword n_cols, const typename arma_Mat_Col_Row_only<obj_type>::result* junk = 0)
   {
   arma_extra_debug_sigprint();
   arma_ignore(junk);
   
-  return Gen<typename mat_type::elem_type, gen_randn>(n_rows, n_cols);
+  if(is_Col<obj_type>::value == true)
+    {
+    arma_debug_check( (n_cols != 1), "randn(): incompatible size" );
+    }
+  else
+  if(is_Row<obj_type>::value == true)
+    {
+    arma_debug_check( (n_rows != 1), "randn(): incompatible size" );
+    }
+  
+  return Gen<obj_type, gen_randn>(n_rows, n_cols);
   }
 
 
@@ -107,8 +117,7 @@ arma_inline
 const GenCube<typename cube_type::elem_type, gen_randn>
 randn(const uword n_rows, const uword n_cols, const uword n_slices, const typename arma_Cube_only<cube_type>::result* junk = 0)
   {
-  arma_extra_debug_sigprint();
-  
+  arma_extra_debug_sigprint();  
   arma_ignore(junk);
   
   return GenCube<typename cube_type::elem_type, gen_randn>(n_rows, n_cols, n_slices);
